import { type DebugGranularity, type DebugTargets, type Logger } from '@jvalue/jayvee-execution';
import { type JayveeModel, type JayveeServices, type PipelineDefinition, type RuntimeParameterProvider, type WrapperFactoryProvider } from '@jvalue/jayvee-language-server';
import { LoggerFactory } from './logging';
import { ExitCode } from './parsing-util';
export interface InterpreterOptions {
    pipelineMatcher: (pipelineDefinition: PipelineDefinition) => boolean;
    env: Map<string, string>;
    debug: boolean;
    debugGranularity: DebugGranularity;
    debugTarget: DebugTargets;
}
export interface JayveeInterpreter {
    /**
     * Interprets a parsed Jayvee model.
     *
     * @param extractAstNodeFn the Jayvee model.
     * @returns the exit code indicating whether interpretation was successful or not.
     */
    interpretModel(model: JayveeModel): Promise<ExitCode>;
    /**
     * Interprets a file as a Jayvee model.
     * Parses the file first as a Jayvee model.
     *
     * @param filePath the file path to the Jayvee model.
     * @returns the exit code indicating whether interpretation was successful or not.
     */
    interpretFile(filePath: string): Promise<ExitCode>;
    /**
     * Interprets a string as a Jayvee model.
     * Parses the string first as a Jayvee model.
     *
     * @param modelString the Jayvee model string.
     * @returns the exit code indicating whether interpretation was successful or not.
     */
    interpretString(modelString: string): Promise<ExitCode>;
    /**
     * Parses a model without executing it.
     * Also sets up the environment so that the model can be properly executed.
     *
     * @param extractAstNodeFn method that extracts the AST node
     * @returns the parsed Jayvee model, or undefined on failure.
     */
    parseModel(extractAstNodeFn: (services: JayveeServices, loggerFactory: LoggerFactory) => Promise<JayveeModel>): Promise<JayveeModel | undefined>;
}
export declare class DefaultJayveeInterpreter implements JayveeInterpreter {
    private readonly options;
    private readonly services;
    private readonly loggerFactory;
    private readonly workspaces;
    private isWorkspaceInitialized;
    constructor(options: InterpreterOptions);
    addWorkspace(uri: string): DefaultJayveeInterpreter;
    interpretModel(model: JayveeModel): Promise<ExitCode>;
    interpretFile(filePath: string): Promise<ExitCode>;
    interpretString(modelString: string): Promise<ExitCode>;
    parseModel(extractAstNodeFn: (services: JayveeServices, loggerFactory: LoggerFactory) => Promise<JayveeModel>): Promise<JayveeModel | undefined>;
    private setupJayveeServices;
    private setupRuntimeParameterProvider;
    private interpretJayveeModel;
    private runPipeline;
    private prepareInterpretation;
}
export declare function logPipelineOverview(pipeline: PipelineDefinition, runtimeParameterProvider: RuntimeParameterProvider, logger: Logger, wrapperFactories: WrapperFactoryProvider): void;
